/*
 *  Nombre: NRF24L01.h
 *  
 *	Autor: Rubn Flores A.
 *
 *	Proyecto: Diseo de una interfaz para sistemas de control en Java 
 *	con comunicacin inalmbrica utilizando un microcontrolador AVR 
 *	con interfaz USB.
 *
 *	Descripcin: Archivo de cabecera para NRF24L01.c
 *  contiene definiciones y constantes utilizadas para
 *	el control y configuracin del NRF24L01+.
 *	
 */ 

/*  Configuracin de pines. */

#define IRQ					PD3			// Interrupcion del NRF24L01. Conectada a INT1.
#define IRQ_PIN				PIND3		
#define SPI_PORT			PORTB		// Puerto del SPI en el AVR. Generalmente es el PORTB.
#define CE					PB1			// Pin15 del ATMEGA 8.	CE del NRF24L01. (configur de salida).	
#define CSN					PB2			// Pin16 del ATMEGA 8.	Chip Select del NRF24L01. (configurar de salida).
#define MOSI				PB3			// Pin17 del ATMEGA 8.	MOSI del AVR (configurar de salida).
#define MISO				PB4			// Pin18 del ATMEGA 8.	MISO del AVR (configurar de entrada).
#define SCK					PB5			// Pin19 del ATMEGA 8.	SCK del AVR(configurar de salida).

#define RF_Select			SPI_PORT &= ~(1<<CSN)
#define RF_Select_Not		SPI_PORT |= (1<<CSN)

#define RF_CE_Low			SPI_PORT &= ~(1<<CE)
#define RF_CE_High			SPI_PORT |= (1<<CE)


#define Payload_Data_Pipe0		1		// Poner en 1 (No se utiliza mas que para el AA.)


/* COMANDOS nRF24L01+*/

#define R_REGISTER			0x00
#define W_REGISTER			0x20
#define R_RX_PAYLOAD		0x61
#define W_TX_PAYLOAD		0xA0
#define FLUSH_TX			0xE1
#define FLUSH_RX			0xE2
#define REUSE_TX_PL			0xE3
#define R_RX_PL_WID			0x60
#define W_ACK_PAYLOAD_PP0	0xA8
#define W_ACK_PAYLOAD_PP1	0xA9
#define W_ACK_PAYLOAD_PP2	0xAA
#define W_ACK_PAYLOAD_PP3	0xAB
#define W_ACK_PAYLOAD_PP4	0xAC
#define W_ACK_PAYLOAD_PP5	0xAD	
#define W_TX_PAYLOAD_NO_ACK	0xB0	
#define NOP_RF				0xFF
#define ACTIVATE			0x50

/* REGISTROS NRF24L01  
	Usar  operador lgico | (OR) con comando R_REGISTER o W_REGISTER 
	para leer o escribir respectivamente dicho registro. 
*/

#define CONFIG_RF		0x00 //Configuration Register
#define EN_AA			0x01 //Enable Auto Acknowledgment Function
#define EN_RXADDR		0x02 //Enabled RX Addresses
#define SETUP_AW		0x03 //Enabled RX Addresses
#define SETUP_RETR		0x04 //Setup of Automatic Retransmission
#define RF_CH			0x05 //RF Channel
#define RF_SETUP		0x06 //RF Setup Register
#define	RF_SETUP_SPEED_1Mbps	0b00000110 // 0x06
#define	RF_SETUP_SPEED_2Mbps	0b00001110 // 0x0E
#define	RF_SETUP_SPEED_250Kbps	0b00100110 // 0x26
#define STATUS_RF		0x07 //Status Register 
#define OBSERVE_TX		0x08 //Transmit observe register
#define RX_ADDR_P0		0x0A //Receive address data pipe 0. 5 Bytes max length.
#define RX_ADDR_P1		0x0B //Receive address data pipe 1. 5 Bytes max length.
#define RX_ADDR_P2		0x0C //Receive address data pipe 2. 5 Bytes max length.
#define RX_ADDR_P3		0x0D //Receive address data pipe 3. 5 Bytes max length.
#define RX_ADDR_P4		0x0E //Receive address data pipe 4. 5 Bytes max length.
#define RX_ADDR_P5		0x0F //Receive address data pipe 5. 5 Bytes max length.
#define TX_ADDR			0x10 //Transmit address. 
#define RX_PW_P0		0x11 // # of bytes in RX payload in data pipe 0 (1 to 32 bytes).
#define RX_PW_P1		0x12 // # of bytes in RX payload in data pipe 1 (1 to 32 bytes).
#define RX_PW_P2		0x13 // # of bytes in RX payload in data pipe 2 (1 to 32 bytes).
#define RX_PW_P3		0x14 // # of bytes in RX payload in data pipe 3 (1 to 32 bytes).
#define RX_PW_P4		0x15 // # of bytes in RX payload in data pipe 4 (1 to 32 bytes).
#define RX_PW_P5		0x16 // # of bytes in RX payload in data pipe 5 (1 to 32 bytes).
#define FIFO_STATUS		0x17 // FIFO Status Register
#define DYNPD			0x1C // Enable dynamic payload length
#define FEATURE			0x1D // Feature Register


/* Bits del registro CONFIG*/
#define MASK_RX_DR		6	// Mask interrupt caused by RX_DR (Recepcion exitosa)
//1: Interrupt not reflected on the IRQ pin
//0: Reflect RX_DR as active low interrupt on the IRQ pin
#define MASK_TX_DS		5	//Mask interrupt caused by TX_DS (Transmision exitosa)
//1: Interrupt not reflected on the IRQ pin
//0: Reflect TX_DS as active low interrupt on the IRQ pin
#define MASK_MAX_RT		4  //Mask interrupt caused by MAX_RT (Max. Reintentos)
//1: Interrupt not reflected on the IRQ pin
//0: Reflect MAX_RT as active low interrupt on the IRQ pin

/* Bits del registro STATUS*/
#define RX_DR			6	//Data Ready RX FIFO interrupt. Set high
//when new data arrives RX FIFO. Write 1 to clear bit.

#define	TX_DS			5	//Data Sent TX FIFO interrupt. Set high
//when packet sent on TX. If AUTO_ACK is activated, this bit will be set high only
//when ACK is received. Write 1 to clear bit.

#define MAX_RT			4	//Maximum number of TX retries interrupt
//Write 1 to clear bit. If MAX_RT is set it must be cleared to enable
//further communication.

#define RX_P_NO3		3	 // Data pipe number for the payload

#define RX_P_NO2		2	// available for reading from RX_FIFO
// 000-101: Data Pipe Number
// 110: Not Used
// 111: RX FIFO Empty
#define RX_P_NO1		1

#define TX_FULL			0	// TX FIFO full flag. 1: TX FIFO full. 0:
// Available locations in TX FIFO.


